/**
 * 种子管理 API
 */
import api from './index'

export const torrentsApi = {
  // 获取种子列表
  getTorrents(clientIds = []) {
    const params = clientIds.length > 0 ? { client_ids: clientIds } : {}
    return api.get('/torrents', { params })
  },

  // 获取主要数据（聚合接口）
  getMainData(clientIds = []) {
    const params = clientIds.length > 0 ? { client_ids: clientIds } : {}
    return api.get('/torrents/maindata', { params })
  },

  // 暂停种子
  pauseTorrents(hashes, clientId = null) {
    return api.post('/torrents/pause', {
      hashes,
      client_id: clientId
    })
  },

  // 恢复种子
  resumeTorrents(hashes, clientId = null) {
    return api.post('/torrents/resume', {
      hashes,
      client_id: clientId
    })
  },

  // 删除种子
  deleteTorrents(hashes, deleteFiles = false, clientId = null) {
    return api.post('/torrents/delete', {
      hashes,
      delete_files: deleteFiles,
      client_id: clientId
    })
  },

  // 获取种子详细信息
  getTorrentDetails(torrentHash, clientId) {
    return api.get(`/torrents/${torrentHash}/details`, {
      params: { client_id: clientId }
    })
  },

  // 添加种子文件
  addTorrentFile(clientId, file, options = {}) {
    const formData = new FormData()
    formData.append('client_id', clientId)
    formData.append('torrent_file', file)

    // 添加可选参数
    if (options.category) formData.append('category', options.category)
    if (options.tags) formData.append('tags', options.tags)
    if (options.savePath) formData.append('save_path', options.savePath)
    if (options.paused) formData.append('paused', options.paused.toString())

    return api.post('/torrents/add', formData, {
      headers: {
        'Content-Type': 'multipart/form-data'
      }
    })
  },

  // 添加磁力链接
  addMagnetLink(clientId, magnetLink, options = {}) {
    return api.post('/torrents/add', {
      client_id: clientId,
      magnet_link: magnetLink,
      options
    })
  },

  // 添加种子URL
  addTorrentUrl(clientId, torrentUrl, options = {}) {
    return api.post('/torrents/add', {
      client_id: clientId,
      torrent_url: torrentUrl,
      options
    })
  }
}
