/**
 * 应用全局状态管理
 */
import { defineStore } from 'pinia'
import { ref } from 'vue'

export const useAppStore = defineStore('app', () => {
  // 状态
  const theme = ref('light')
  const sidebarCollapsed = ref(false)
  const refreshInterval = ref(5000) // 5秒刷新间隔
  const autoRefresh = ref(true)

  // 操作方法
  const toggleTheme = () => {
    theme.value = theme.value === 'light' ? 'dark' : 'light'
    // 保存到本地存储
    localStorage.setItem('theme', theme.value)
  }

  const toggleSidebar = () => {
    sidebarCollapsed.value = !sidebarCollapsed.value
  }

  const setRefreshInterval = (interval) => {
    refreshInterval.value = interval
    localStorage.setItem('refreshInterval', interval.toString())
  }

  const toggleAutoRefresh = () => {
    autoRefresh.value = !autoRefresh.value
    localStorage.setItem('autoRefresh', autoRefresh.value.toString())
  }

  const initializeSettings = () => {
    // 从本地存储恢复设置
    const savedTheme = localStorage.getItem('theme')
    if (savedTheme) {
      theme.value = savedTheme
    }

    const savedInterval = localStorage.getItem('refreshInterval')
    if (savedInterval) {
      refreshInterval.value = parseInt(savedInterval)
    }

    const savedAutoRefresh = localStorage.getItem('autoRefresh')
    if (savedAutoRefresh) {
      autoRefresh.value = savedAutoRefresh === 'true'
    }
  }

  return {
    // 状态
    theme,
    sidebarCollapsed,
    refreshInterval,
    autoRefresh,
    
    // 方法
    toggleTheme,
    toggleSidebar,
    setRefreshInterval,
    toggleAutoRefresh,
    initializeSettings
  }
})
